:root{--main-light: hsl(320deg 80% 48%);--main-2-light: hsl(320deg 100% 67%);--text-color-light: hsl(0deg 0% 0%);--secondary-text-color-light: hsl(0deg 0% 15%);--bg-light: hsl(180deg 30% 90%);--secondary-bg-light: hsl(180deg 10% 75%);--tertiary-bg-light: hsl(180deg 48% 77%);--contrast-light: hsl(195deg 90% 44%);--contrast-2-light: hsl(240deg 100% 50%);--main-dark: hsl(320deg 100% 67%);--main-2-dark: hsl(320deg 80% 48%);--text-color-dark: hsl(0deg 0% 90%);--secondary-text-color-dark: hsl(0deg 0% 70%);--bg-dark: hsl(0deg 0% 0%);--secondary-bg-dark: hsl(0deg 0% 9%);--tertiary-bg-dark: hsl(0deg 0% 18%);--contrast-dark: hsl(0deg 90% 48%);--contrast-2-dark: hsl(0deg 90% 62%)}
/*# sourceMappingURL=pink.css.map */
